@@ -1,8 +1,9 @@
 package Crypt::OpenPGP;
 use strict;
+use warnings;
 use 5.008_001;
 
-our $VERSION = '1.12'; # VERSION
+our $VERSION = '1.19'; # VERSION
 
 use Crypt::OpenPGP::Constants qw( DEFAULT_CIPHER );
 use Crypt::OpenPGP::KeyRing;
@@ -18,7 +19,7 @@ use base qw( Crypt::OpenPGP::ErrorHandler );
 use File::HomeDir;
 use File::Spec;
 
-use vars qw( %COMPAT );
+our %COMPAT;
 
 ## pgp2 and pgp5 do not trim trailing whitespace from "canonical text"
 ## signatures, only from cleartext signatures.
@@ -363,9 +364,10 @@ sub verify {
     } else {
         return $pgp->error("SigFile contents are strange");
     }
+    my @pte = ($sig->{type} == 1 ? (Mode => "t") : () );
     unless ($data) {
         if ($param{Data}) {
-            $data = Crypt::OpenPGP::Plaintext->new( Data => $param{Data} );
+            $data = Crypt::OpenPGP::Plaintext->new( Data => $param{Data}, @pte );
         }
         else {
             ## if no Signature or detached sig in SigFile
@@ -374,7 +376,7 @@ sub verify {
             my $fdata = $pgp->_read_files(@files);
             return $pgp->error("Reading data files failed: " . $pgp->errstr)
                 unless defined $fdata;
-            $data = Crypt::OpenPGP::Plaintext->new( Data => $fdata );
+            $data = Crypt::OpenPGP::Plaintext->new( Data => $fdata, @pte );
        }
     }
     my($cert, $kb);
@@ -394,7 +396,7 @@ sub verify {
                 unpack('H*', $key_id))
                 unless $kb;
         }
-        $cert = $kb->signing_key;
+        $cert = $kb->key_by_id($sig->key_id);
     }
 
 ## pgp2 and pgp5 do not trim trailing whitespace from "canonical text"
@@ -608,7 +610,7 @@ sub decrypt {
         return $pgp->error("Can't find a secret key to decrypt message")
             unless $kb || $cert;
         if ($kb) {
-            $cert = $kb->encrypting_key;
+            $cert = $kb->key_by_id($sym_key->key_id);
             $cert->uid($kb->primary_uid);
         }
         if ($cert->is_protected) {
@@ -926,6 +928,14 @@ I<Crypt::OpenPGP> has the following high-level interface. On failure,
 all methods will return C<undef> and set the I<errstr> for the object;
 look below at the I<ERROR HANDLING> section for more information.
 
+=head1 RANDOM SOURCE
+
+I<Crypt::OpenPGP> requires a Random source.  I<Bytes::Random::Secure> is
+now specified as a dependency, as some installations failed to have one
+installed.
+
+I<Crypt::Random>, if installed, is used instead.
+
 =head2 Crypt::OpenPGP->new( %args )
 
 Constructs a new I<Crypt::OpenPGP> instance and returns that object.
